import { Logger } from '@nestjs/common';
import { NestFactory } from '@nestjs/core';
import { NestExpressApplication } from '@nestjs/platform-express';
import { join } from 'path';
import { AppModule } from './app.module';
import { PREFIX } from './config/router';
import { injectTemplateVars } from './config/template.var';
import { HttpExceptionFilter } from './filter/httpException.filter';
import { AuthInterceptor } from './interceptor/auth.interceptor';
import { ErrorsInterceptor } from './interceptor/errors.interceptor';
import { LoggingInterceptor } from './interceptor/logging.interceptor';
import { TimeoutInterceptor } from './interceptor/timeout.interceptor';

const { PORT = 4000 } = process.env;

async function bootstrap() {
  const app = await NestFactory.create<NestExpressApplication>(AppModule);
  const logger: Logger = new Logger('main.ts');

  app
    .useStaticAssets(join(process.cwd(), 'public'), { prefix: '/' })
    .setViewEngine('ejs')
    .setBaseViewsDir(join(process.cwd(), 'src/view'))
    .setGlobalPrefix(PREFIX)
    .useGlobalInterceptors(
      new LoggingInterceptor(),
      new ErrorsInterceptor(),
      new TimeoutInterceptor(),
      new AuthInterceptor(),
    )
    .useGlobalFilters(new HttpExceptionFilter());

  injectTemplateVars(app);

  await app.listen(PORT, () => {
    logger.log(`服务已启动,访问:http://localhost:${PORT}/${PREFIX}`);
  });
}
bootstrap();
